You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/02 12:25:26 UTC

svn commit: r1209415 [9/19] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mail...

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java Fri Dec  2 11:24:48 2011
@@ -24,8 +24,8 @@ import java.util.Map;
 
 import org.apache.struts2.convention.annotation.Action;
 
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java Fri Dec  2 11:24:48 2011
@@ -20,9 +20,9 @@
  */
 package org.apache.struts2.convention;
 
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention;
 
-import org.apache.struts2.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.ConfigurationException;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java Fri Dec  2 11:24:48 2011
@@ -69,7 +69,7 @@ public @interface Result {
      * @return  The name of the result mapping. This is the value that is returned from the action
      *          method and is used to associate a location with a return value.
      */
-    String name() default org.apache.struts2.xwork2.Action.SUCCESS;
+    String name() default com.opensymphony.xwork2.Action.SUCCESS;
 
     /**
      * @return  The location of the result within the web application or anywhere on disk. This location

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@
     "http://struts.apache.org/dtds/struts-2.1.7.dtd">
 
 <struts order="20">
-  <bean type="org.apache.struts2.xwork2.UnknownHandler" name="convention" class="org.apache.struts2.convention.ConventionUnknownHandler"/>
+  <bean type="com.opensymphony.xwork2.UnknownHandler" name="convention" class="org.apache.struts2.convention.ConventionUnknownHandler"/>
 
   <bean type="org.apache.struts2.convention.ActionConfigBuilder" name="convention" class="org.apache.struts2.convention.PackageBasedActionConfigBuilder"/>
   <bean type="org.apache.struts2.convention.ActionNameBuilder" name="convention" class="org.apache.struts2.convention.SEOActionNameBuilder"/>
@@ -35,8 +35,8 @@
   <bean type="org.apache.struts2.convention.InterceptorMapBuilder" name="convention" class="org.apache.struts2.convention.DefaultInterceptorMapBuilder"/>
   <bean type="org.apache.struts2.convention.ConventionsService" name="convention" class="org.apache.struts2.convention.ConventionsServiceImpl"/>
 
-  <bean type="org.apache.struts2.xwork2.config.PackageProvider" name="convention.packageProvider" class="org.apache.struts2.convention.ClasspathPackageProvider"/>
-  <bean type="org.apache.struts2.xwork2.config.PackageProvider" name="convention.containerProvider" class="org.apache.struts2.convention.ClasspathConfigurationProvider"/>
+  <bean type="com.opensymphony.xwork2.config.PackageProvider" name="convention.packageProvider" class="org.apache.struts2.convention.ClasspathPackageProvider"/>
+  <bean type="com.opensymphony.xwork2.config.PackageProvider" name="convention.containerProvider" class="org.apache.struts2.convention.ClasspathConfigurationProvider"/>
 
   <constant name="struts.convention.actionConfigBuilder" value="convention"/>
   <constant name="struts.convention.actionNameBuilder" value="convention"/>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java Fri Dec  2 11:24:48 2011
@@ -20,10 +20,10 @@
  */
 package org.apache.struts2.convention;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
-import org.apache.struts2.xwork2.inject.Container;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
+import com.opensymphony.xwork2.inject.Container;
 import junit.framework.TestCase;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.classextension.EasyMock.createMock;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java Fri Dec  2 11:24:48 2011
@@ -42,10 +42,10 @@ import org.apache.struts2.convention.ann
 import org.easymock.EasyMock;
 import org.easymock.IAnswer;
 
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
-import org.apache.struts2.xwork2.inject.Container;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
+import com.opensymphony.xwork2.inject.Container;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java Fri Dec  2 11:24:48 2011
@@ -68,24 +68,24 @@ import org.apache.struts2.convention.ann
 import org.apache.struts2.dispatcher.ServletDispatcherResult;
 import org.easymock.EasyMock;
 
-import org.apache.struts2.xwork2.ObjectFactory;
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.Result;
-import org.apache.struts2.xwork2.ActionChainResult;
-import org.apache.struts2.xwork2.util.reflection.ReflectionException;
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
-import org.apache.struts2.xwork2.config.entities.InterceptorConfig;
-import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
-import org.apache.struts2.xwork2.config.entities.InterceptorStackConfig;
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
-import org.apache.struts2.xwork2.config.impl.DefaultConfiguration;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Scope.Strategy;
-import org.apache.struts2.xwork2.ognl.OgnlReflectionProvider;
+import com.opensymphony.xwork2.ObjectFactory;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.Result;
+import com.opensymphony.xwork2.ActionChainResult;
+import com.opensymphony.xwork2.util.reflection.ReflectionException;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.InterceptorConfig;
+import com.opensymphony.xwork2.config.entities.InterceptorMapping;
+import com.opensymphony.xwork2.config.entities.InterceptorStackConfig;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
+import com.opensymphony.xwork2.config.impl.DefaultConfiguration;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Scope.Strategy;
+import com.opensymphony.xwork2.ognl.OgnlReflectionProvider;
 
 import javax.servlet.ServletContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java Fri Dec  2 11:24:48 2011
@@ -1,7 +1,7 @@
 package org.apache.struts2.convention;
 
-import org.apache.struts2.xwork2.ActionInvocation;
-import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import com.opensymphony.xwork2.ActionInvocation;
+import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
 
 public class TestInterceptor extends AbstractInterceptor {
 	private String string1;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions;
 
-import org.apache.struts2.xwork2.Action;
+import com.opensymphony.xwork2.Action;
 
 public class Skip implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.action;
 
-import org.apache.struts2.xwork2.ActionSupport;
+import com.opensymphony.xwork2.ActionSupport;
 
 public abstract class TestBase extends ActionSupport {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import org.apache.struts2.convention.ann
  * This is a test action.
  * </p>
  */
-public class SingleActionNameAction2 implements org.apache.struts2.xwork2.Action{
+public class SingleActionNameAction2 implements com.opensymphony.xwork2.Action{
     @Action("action345")
     public String execute() {
         return null;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.idx;
 
-import org.apache.struts2.xwork2.Action;
+import com.opensymphony.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.idx.idx2;
 
-import org.apache.struts2.xwork2.Action;
+import com.opensymphony.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.result;
 
-import org.apache.struts2.xwork2.ActionSupport;
+import com.opensymphony.xwork2.ActionSupport;
 import org.apache.struts2.convention.annotation.Result;
 
 @Result(name="error", location="error.jsp", params={"key", "value", "key1", "value1"})

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.skip;
 
-import org.apache.struts2.xwork2.Action;
+import com.opensymphony.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java Fri Dec  2 11:24:48 2011
@@ -30,7 +30,7 @@ import org.apache.struts2.components.Clo
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * AbstractRemoteCallUIBean is superclass for all components dealing with remote

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Form;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * Base class for tags that perform AJAX validation

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java Fri Dec  2 11:24:48 2011
@@ -31,7 +31,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java Fri Dec  2 11:24:48 2011
@@ -22,6 +22,7 @@
 package org.apache.struts2.dojo.components;
 
 import java.text.DateFormat;
+import java.text.Format;
 import java.text.MessageFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -38,9 +39,9 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: notice -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java Fri Dec  2 11:24:48 2011
@@ -33,9 +33,9 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java Fri Dec  2 11:24:48 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.dojo.components;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 import org.apache.struts2.components.ClosingUIBean;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.views.annotations.StrutsTag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java Fri Dec  2 11:24:48 2011
@@ -34,7 +34,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java Fri Dec  2 11:24:48 2011
@@ -31,7 +31,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java Fri Dec  2 11:24:48 2011
@@ -41,7 +41,7 @@ import org.apache.struts2.dojo.views.vel
 import org.apache.struts2.dojo.views.velocity.components.TreeNodeDirective;
 import org.apache.struts2.views.TagLibrary;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 public class DojoTagLibrary implements TagLibrary {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Anchor;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Anchor

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Autocompleter;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Autocompleter

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Bind;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Bind

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.DateTimePicker;
 import org.apache.struts2.views.freemarker.tags.TextFieldModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see DropdownDateTimePicker

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Div;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java Fri Dec  2 11:24:48 2011
@@ -24,7 +24,7 @@ package org.apache.struts2.dojo.views.fr
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 public class DojoModels {
     protected DateTimePickerModel dateTimePicker;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Head;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Head

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Submit;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Submit

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TabbedPanel;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TabbedPanel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TextArea;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TextArea

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Tree;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * TreeModel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TreeNode;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * TreeNodeModel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Anchor;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Anchor

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Autocompleter;
 import org.apache.struts2.views.jsp.ui.ComboBoxTag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Autocompleter

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/BindTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/BindTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/BindTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/BindTag.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Bind;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 public class BindTag extends AbstractValidateTag {
     protected String targets;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DateTimePickerTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DateTimePickerTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DateTimePickerTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DateTimePickerTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.DateTimePicker;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see DateTimePicker

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DivTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DivTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DivTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/DivTag.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Div;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 public class DivTag extends AbstractRemoteTag {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/HeadTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/HeadTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/HeadTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/HeadTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Head;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Head

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/SubmitTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/SubmitTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/SubmitTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/SubmitTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Submit;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Submit

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TabbedPanelTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TabbedPanelTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TabbedPanelTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TabbedPanelTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TabbedPanel;
 import org.apache.struts2.views.jsp.ui.AbstractClosingTag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TabbedPanel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TextareaTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TextareaTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TextareaTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TextareaTag.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.TextArea;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeNodeTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeNodeTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeNodeTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeNodeTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TreeNode;
 import org.apache.struts2.views.jsp.ui.AbstractClosingTag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TreeNode

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeTag.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/TreeTag.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Tree;
 import org.apache.struts2.views.jsp.ui.AbstractClosingTag;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Tree

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AnchorDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AnchorDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AnchorDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AnchorDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Anchor;
 import org.apache.struts2.components.Component;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Anchor

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AutocompleterDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AutocompleterDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AutocompleterDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/AutocompleterDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Autocompleter;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Autocompleter

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/BindDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/BindDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/BindDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/BindDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Bind;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Bind

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DateTimePickerDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DateTimePickerDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DateTimePickerDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DateTimePickerDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.DateTimePicker;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see DateTimePicker

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DivDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DivDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DivDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/DivDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Div;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Div

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/HeadDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/HeadDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/HeadDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/HeadDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Head;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Head

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/SubmitDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/SubmitDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/SubmitDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/SubmitDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Submit;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see Submit

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TabbedPanelDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TabbedPanelDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TabbedPanelDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TabbedPanelDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.TabbedPanel;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TabbedPanel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TextAreaDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TextAreaDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TextAreaDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TextAreaDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.TextArea;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * @see TextArea

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Tree;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <code>TreeDirective</code>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeNodeDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeNodeDirective.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeNodeDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/velocity/components/TreeNodeDirective.java Fri Dec  2 11:24:48 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.TreeNode;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 /**
  * <code>TreeNodeDirective</code>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/TestAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/TestAction.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/TestAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/TestAction.java Fri Dec  2 11:24:48 2011
@@ -26,8 +26,8 @@ import java.util.List;
 import java.util.Map;
 
 
-import org.apache.struts2.xwork2.Action;
-import org.apache.struts2.xwork2.ActionSupport;
+import com.opensymphony.xwork2.Action;
+import com.opensymphony.xwork2.ActionSupport;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java Fri Dec  2 11:24:48 2011
@@ -39,10 +39,10 @@ import org.apache.struts2.dojo.TestActio
 import org.apache.struts2.dojo.components.Head;
 
 import com.mockobjects.dynamic.Mock;
-import org.apache.struts2.xwork2.Action;
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.Action;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java Fri Dec  2 11:24:48 2011
@@ -38,9 +38,9 @@ import java.util.StringTokenizer;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;
 
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  */

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/TreeTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/TreeTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/TreeTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/TreeTest.java Fri Dec  2 11:24:48 2011
@@ -22,8 +22,8 @@
 package org.apache.struts2.dojo.views.jsp.ui;
 
 
-import org.apache.struts2.xwork2.Action;
-import org.apache.struts2.xwork2.ActionSupport;
+import com.opensymphony.xwork2.Action;
+import com.opensymphony.xwork2.ActionSupport;
 
 /**
  * Test case for Tree component.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dwr/src/main/java/org/apache/struts2/validators/DWRValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dwr/src/main/java/org/apache/struts2/validators/DWRValidator.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dwr/src/main/java/org/apache/struts2/validators/DWRValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dwr/src/main/java/org/apache/struts2/validators/DWRValidator.java Fri Dec  2 11:24:48 2011
@@ -32,18 +32,24 @@ import org.apache.struts2.dispatcher.App
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.dispatcher.RequestMap;
 import org.apache.struts2.dispatcher.SessionMap;
+import org.apache.struts2.dispatcher.mapper.ActionMapper;
+import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
 import uk.ltd.getahead.dwr.WebContextFactory;
 
-import org.apache.struts2.xwork2.Action;
-import org.apache.struts2.xwork2.ActionProxy;
-import org.apache.struts2.xwork2.ActionProxyFactory;
-import org.apache.struts2.xwork2.DefaultActionInvocation;
-import org.apache.struts2.xwork2.ValidationAware;
-import org.apache.struts2.xwork2.ValidationAwareSupport;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.Action;
+import com.opensymphony.xwork2.ActionInvocation;
+import com.opensymphony.xwork2.ActionProxy;
+import com.opensymphony.xwork2.ActionProxyFactory;
+import com.opensymphony.xwork2.DefaultActionInvocation;
+import com.opensymphony.xwork2.ValidationAware;
+import com.opensymphony.xwork2.ValidationAwareSupport;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  * <p/>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/EmbeddedJSPResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/EmbeddedJSPResult.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/EmbeddedJSPResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/EmbeddedJSPResult.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2;
 
-import org.apache.struts2.xwork2.ActionInvocation;
+import com.opensymphony.xwork2.ActionInvocation;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.dispatcher.StrutsResultSupport;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPLoader.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPLoader.java Fri Dec  2 11:24:48 2011
@@ -20,12 +20,12 @@
  */
 package org.apache.struts2;
 
-import org.apache.struts2.xwork2.util.URLUtil;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterfaceDelegate;
-import org.apache.struts2.xwork2.util.finder.UrlSet;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.URLUtil;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterfaceDelegate;
+import com.opensymphony.xwork2.util.finder.UrlSet;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang.StringUtils;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPRuntime.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPRuntime.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPRuntime.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/JSPRuntime.java Fri Dec  2 11:24:48 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2;
 
-import org.apache.struts2.xwork2.ActionContext;
+import com.opensymphony.xwork2.ActionContext;
 import org.apache.struts2.views.util.UrlHelper;
 
 import javax.servlet.Servlet;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspC.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspC.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspC.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspC.java Fri Dec  2 11:24:48 2011
@@ -28,6 +28,7 @@ import java.io.FileWriter;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.Writer;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLClassLoader;
 import java.util.*;
@@ -42,7 +43,7 @@ import org.apache.struts2.jasper.servlet
 import org.apache.struts2.jasper.xmlparser.ParserUtils;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
 
 /**
  * Shell for the jspc compiler.  Handles all options associated with the

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspCompilationContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspCompilationContext.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspCompilationContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/JspCompilationContext.java Fri Dec  2 11:24:48 2011
@@ -17,7 +17,7 @@
 
 package org.apache.struts2.jasper;
 
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.jasper.compiler.Compiler;
 import org.apache.struts2.jasper.compiler.JspRuntimeContext;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/servlet/JspCServletContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/servlet/JspCServletContext.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/servlet/JspCServletContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/main/java/org/apache/struts2/jasper/servlet/JspCServletContext.java Fri Dec  2 11:24:48 2011
@@ -18,8 +18,8 @@
 package org.apache.struts2.jasper.servlet;
 
 
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
-import org.apache.struts2.xwork2.ActionContext;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.ActionContext;
 
 import java.io.File;
 import java.io.InputStream;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/test/java/org/apache/struts2/EmbeddedJSPResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/test/java/org/apache/struts2/EmbeddedJSPResultTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/test/java/org/apache/struts2/EmbeddedJSPResultTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/embeddedjsp/src/test/java/org/apache/struts2/EmbeddedJSPResultTest.java Fri Dec  2 11:24:48 2011
@@ -20,12 +20,12 @@
  */
 package org.apache.struts2;
 
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.util.ValueStack;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterfaceDelegate;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterfaceDelegate;
 import junit.framework.TestCase;
 import org.apache.commons.lang.StringUtils;
 import org.easymock.EasyMock;
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java Fri Dec  2 11:24:48 2011
@@ -20,28 +20,28 @@
  */
 package org.apache.struts2.convention;
 
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.ObjectFactory;
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
-import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.util.FileManager;
-import org.apache.struts2.xwork2.util.TextParseUtil;
-import org.apache.struts2.xwork2.util.classloader.ReloadingClassLoader;
-import org.apache.struts2.xwork2.util.finder.ClassFinder;
-import org.apache.struts2.xwork2.util.finder.ClassFinder.ClassInfo;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
-import org.apache.struts2.xwork2.util.finder.ClassLoaderInterfaceDelegate;
-import org.apache.struts2.xwork2.util.finder.Test;
-import org.apache.struts2.xwork2.util.finder.UrlSet;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.ObjectFactory;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.InterceptorMapping;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.util.FileManager;
+import com.opensymphony.xwork2.util.TextParseUtil;
+import com.opensymphony.xwork2.util.classloader.ReloadingClassLoader;
+import com.opensymphony.xwork2.util.finder.ClassFinder;
+import com.opensymphony.xwork2.util.finder.ClassFinder.ClassInfo;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
+import com.opensymphony.xwork2.util.finder.ClassLoaderInterfaceDelegate;
+import com.opensymphony.xwork2.util.finder.Test;
+import com.opensymphony.xwork2.util.finder.UrlSet;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.StrutsConstants;
@@ -470,7 +470,7 @@ public class PackageBasedActionConfigBui
     /**
      * Note that we can't include the test for {@link #actionSuffix} here
      * because a class is included if its name ends in {@link #actionSuffix} OR
      * it implements {@link org.apache.struts2.xwork2.Action}. Since the whole
      * goal is to avoid loading the class if we don't have to, the (actionSuffix
      * || implements Action) test will have to remain until later. See
      * {@link #getActionClassTest()} for the test performed on the loaded
@@ -551,7 +551,7 @@ public class PackageBasedActionConfigBui
                 boolean nameMatches = classInfo.getName().endsWith(actionSuffix);
 
                 try {
-                    return inPackage && (nameMatches || (checkImplementsAction && org.apache.struts2.xwork2.Action.class.isAssignableFrom(classInfo.get())));
+                    return inPackage && (nameMatches || (checkImplementsAction && com.opensymphony.xwork2.Action.class.isAssignableFrom(classInfo.get())));
                 } catch (ClassNotFoundException ex) {
                     if (LOG.isErrorEnabled())
                         LOG.error("Unable to load class [#0]", ex, classInfo.getName());
@@ -470,7 +470,7 @@ public class PackageBasedActionConfigBui
      * Note that we can't include the test for {@link #actionSuffix} here
      * because a class is included if its name ends in {@link #actionSuffix} OR
-     * it implements {@link org.apache.struts2.xwork2.Action}. Since the whole
+     * it implements {@link com.opensymphony.xwork2.Action}. Since the whole
      * goal is to avoid loading the class if we don't have to, the (actionSuffix
      * || implements Action) test will have to remain until later. See

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================